@@ -102,15 +102,20 @@ def get_confusion_mat(labels1,labels2):
     confusion_matrix[idx,idx]=0
     return confusion_matrix
 
-def debable(labellings_list,pivot):
-    labellings_list.sort(key=lambda x: x.max())
+def debable(labellings,pivot,subsample_size='none'):
+    #labellings_list.sort(key=lambda x: x.max())
+    if isinstance(labellings,np.ndarray):
+        assert labellings.ndim == 2, f"If debabling array, it should have 2 dimensions, but here it has {labellings.ndim}"
+        labellings_list = [r for r in labellings]
+    else:
+        labellings_list = labellings
     if pivot == 'none':
         pivot = labellings_list.pop(0)
         translated_list = [pivot]
     else:
         translated_list = []
     for not_lar in labellings_list:
-        not_lar_translated = translate_labellings(not_lar,pivot)
+        not_lar_translated = translate_labellings(not_lar,pivot,subsample_size=subsample_size)
         translated_list.append(not_lar_translated)
     return translated_list
 
